@@ -11,7 +11,7 @@ app_name = "naked"
 #------------------------------------------------------------------------------
 major_version = "0"
 minor_version = "1"
-patch_version = "18"
+patch_version = "19"
 
 #------------------------------------------------------------------------------
 # Debug Flag (switch to False for production release code)
@@ -52,7 +52,7 @@ The <primary command> is mandatory and includes one of the commands in the follo
 PRIMARY COMMANDS     SECONDARY COMMANDS
 
    build                   help
-   dist           all•help•sdist•wheel•win
+   dist        all•help•sdist•swheel•wheel•win
    help                  - none -
    locate         main•help•settings•setup
    make                    help
